@@ -36,7 +36,7 @@ class Colocalize(QtWidgets.QWidget):
         self._prev_translate_y = 0
 
         # disable widget for shape controls initially
-        self.widget_struct.setEnabled(False)
+        self.groupBox_struct.setEnabled(False)
         self.vis.setEnabled(False)
 
         for tab in [self.tableWidget_paths, self.tableWidget_structures]:
@@ -105,7 +105,14 @@ class Colocalize(QtWidgets.QWidget):
 
     def add_paths(self, paths):
         for pp in paths:
-            self.session_scheme.append(pp)
+            try:
+                self.session_scheme.append(pp)
+            except FileNotFoundError as e:
+                QtWidgets.QMessageBox.critical(
+                    self,
+                    "Associated data file missing or invalid",
+                    e.strerror
+                )
         self.update_table_paths()
 
     def clear(self):
@@ -184,7 +191,7 @@ class Colocalize(QtWidgets.QWidget):
         - Update the structure table
         """
         if self.current_structure_composite:
-            self.widget_struct.setEnabled(True)
+            self.groupBox_struct.setEnabled(True)
             self.vis.setEnabled(True)
             # set available channels in ROI visualization
             self.comboBox_channel.blockSignals(True)
@@ -195,7 +202,7 @@ class Colocalize(QtWidgets.QWidget):
             self.comboBox_channel.blockSignals(False)
             self.update_ui_from_scheme()
         else:
-            self.widget_struct.setEnabled(False)
+            self.groupBox_struct.setEnabled(False)
             self.vis.setEnabled(False)
             self.rois.clear()
 
@@ -242,9 +249,9 @@ class Colocalize(QtWidgets.QWidget):
     def on_image_changed(self, image):
         """Handle image changes in self.vis in the other widgets"""
         if np.isnan(image).all() or self.tableWidget_paths.currentRow() < 0:
-            self.widget_struct.setEnabled(False)
+            self.groupBox_struct.setEnabled(False)
         else:
-            self.widget_struct.setEnabled(True)
+            self.groupBox_struct.setEnabled(True)
             self.update_ui_from_scheme()
 
     @QtCore.pyqtSlot(int)
@@ -344,5 +351,9 @@ class Colocalize(QtWidgets.QWidget):
             self.update_structure_table()
             # set new ROIs
             self.vis.set_data_source(self.current_data_source)
+            # Scale the current shape according to the scale in the current
+            # data source.
+            self.current_structure_composite.set_scale(
+                point_um=self.current_point_um)
             self.rois.set_structure_composite(self.current_structure_composite,
                                               self.vis)
